@@ -37,15 +37,11 @@ async def _prepare_dead_letter_queue(channel: Channel,
                                      dl_queue_name: str,
                                      dl_exchange: str,
                                      dl_exchange_type: str,
-                                     default_queue_params: dict,
+                                     dl_queue_params: dict,
                                      bindings: Optional[list] = []) -> Queue:
-    if "x-dead-letter-exchange" in default_queue_params["arguments"].keys():
-        logger.warning("DL queue parameters can't contain x-dead-letter-exchange field!",
-                       extra={"full_message": "DL queue params: %s" % default_queue_params})
-        d = default_queue_params["arguments"].pop("x-dead-letter-exchange")
     dead_letter_queue: Queue = await channel.declare_queue(
         dl_queue_name,
-        **default_queue_params
+        **dl_queue_params
     )
     await channel.declare_exchange(dl_exchange, dl_exchange_type)
 
@@ -70,6 +66,7 @@ async def run_consumer(consumer_class: RabbitMQConsumer,
                        binding: str,
                        dl_enabled: Optional[bool] = False,
                        dl_queue_name: Optional[str] = None,
+                       dl_queue_params: Optional[dict] = {},
                        dl_exchange_name: Optional[str] = None,
                        dl_exchange_type: Optional[str] = None,
                        dl_bindings: Optional[list] = []) -> None:
@@ -91,7 +88,7 @@ async def run_consumer(consumer_class: RabbitMQConsumer,
                                                                  dl_queue_name,
                                                                  dl_exchange_name,
                                                                  get_exchange_type(dl_exchange_type),
-                                                                 default_queue_params,
+                                                                 dl_queue_params,
                                                                  dl_bindings)
         queue = await _prepare_consumed_queue(channel,
                                               queue_name,
